@@ -312,9 +312,10 @@ sub create($)
 
         $self->print($new);
         $new->close;
+        $self->modified(0);
     }
 
-    $self->filename($filename);
+    $self->Mail::Box::Dir::Message::filename($filename);
     unlink $oldtmp if $oldtmp;
 
     $self;
@@ -328,6 +329,8 @@ sub create($)
 
 L<Mail::Box-Overview>
 
+For support and additional documentation, see http://perl.overmeer.net/mailbox/
+
 =head1 AUTHOR
 
 Mark Overmeer (F<mailbox@overmeer.net>).
@@ -336,9 +339,9 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.012.
+This code is beta, version 2.013.
 
-Copyright (c) 2001 Mark Overmeer. All rights reserved.
+Copyright (c) 2001-2002 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
