@@ -90,27 +90,33 @@ sub unlock()
 #-------------------------------------------
 
 sub lock()
-{   my $self  = shift;
+{   my $self   = shift;
     return 1 if $self->hasLock;
 
     my $lockfile = $self->filename;
-    my $end   = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1 : $self->{MBL_timeout};
-    my $timer = 0;
+    my $end      = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1
+                 : $self->{MBL_timeout};
+    my $expire   = $self->{MBL_expires}/86400;  # in days for -A
 
-    while($timer < $end)
-    {   return $self->{MBL_has_lock} = 1
+    while(1)
+    {
+        return $self->{MBL_has_lock} = 1
            if $self->_try_lock($lockfile);
 
-        if(   -e $lockfile
-           && -A $lockfile > ($self->{MBL_timeout}/86400)
-           && unlink $lockfile
-          )
-        {   warn "Removed expired lockfile $lockfile.\n";
-            redo;
+        if(-e $lockfile && -A $lockfile > $expire)
+        {
+            if(unlink $lockfile)
+            {   warn "Removed expired lockfile $lockfile.\n";
+                redo;
+            }
+            else
+            {   warn "Failed to remove expired lockfile $lockfile: $!\n";
+                last;
+            }
         }
 
+        last unless --$end;
         sleep 1;
-        $timer++;
     }
 
     return 0;
@@ -126,6 +132,8 @@ sub isLocked() { -e shift->filename }
 
 L<Mail::Box-Overview>
 
+For support and additional documentation, see http://perl.overmeer.net/mailbox/
+
 =head1 AUTHOR
 
 Mark Overmeer (F<mailbox@overmeer.net>).
@@ -134,9 +142,9 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.012.
+This code is beta, version 2.013.
 
-Copyright (c) 2001 Mark Overmeer. All rights reserved.
+Copyright (c) 2001-2002 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
