@@ -121,23 +121,28 @@ sub lock()
     my $folder   = $self->{MBL_folder};
     my $lockfile = $self->filename;
     my $tmpfile  = $self->_construct_tmpfile or return;
-    my $end      = $self->{MBL_timeout} eq 'NOTIMEOUT' ? 0
+    my $end      = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1
                  : $self->{MBL_timeout};
+    my $expires  = $self->{MBL_expires}/86400;  # in days for -A
 
-    for(my $timer=0; $timer < $end; $timer++)
+    while(1)
     {   if($self->_try_lock($tmpfile, $lockfile))
         {   $self->{MBL_has_lock} = 1;
             return 1;
         }
 
-        if(   -e $lockfile
-           && -A $lockfile > ($self->{MBL_timeout}/86400)
-           && unlink $lockfile
-          )
-        {   warn "Removed expired lockfile $lockfile.\n";
-            redo;
+        if(-e $lockfile && -A $lockfile > $expires)
+        {   if(unlink $lockfile)
+            {   warn "Removed expired lockfile $lockfile.\n";
+                redo;
+            }
+            else
+            {   warn "Unable to remove expired lockfile $lockfile: $!\n";
+                last;
+            }
         }
 
+        last unless --$end;
         sleep 1;
     }
 
@@ -169,6 +174,8 @@ sub unlock($)
 
 L<Mail::Box-Overview>
 
+For support and additional documentation, see http://perl.overmeer.net/mailbox/
+
 =head1 AUTHOR
 
 Mark Overmeer (F<mailbox@overmeer.net>).
@@ -177,9 +184,9 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.012.
+This code is beta, version 2.013.
 
-Copyright (c) 2001 Mark Overmeer. All rights reserved.
+Copyright (c) 2001-2002 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
