@@ -3,7 +3,7 @@ use strict;
 package Mail::Box::MH;
 use base 'Mail::Box::Dir';
 
-our $VERSION = 2.012;
+our $VERSION = 2.013;
 
 use Mail::Box::MH::Index;
 use Mail::Box::MH::Message;
@@ -46,19 +46,18 @@ L<Mail::Box> (MB), L<Mail::Reporter> (MR), L<Mail::Box::Dir> (MBD).
 
 The general methods for C<Mail::Box::MH> objects:
 
-   MB AUTOLOAD                          MR log [LEVEL [,STRINGS]]
-   MB addMessage  MESSAGE               MB message INDEX [,MESSAGE]
-   MB addMessages MESSAGE [, MESS...    MB messageId MESSAGE-ID [,MESS...
-   MB allMessageIds                     MB messages
-   MB close OPTIONS                     MB modified [BOOLEAN]
-   MB create FOLDERNAME [, OPTIONS]     MB name
-   MB current [NUMBER|MESSAGE|MES...       new OPTIONS
-   MB delete                            MB openSubFolder NAME [,OPTIONS]
-  MBD directory                         MR report [LEVEL]
-   MR errors                            MR reportAll [LEVEL]
-   MB find MESSAGE-ID                   MR trace [LEVEL]
-   MB listSubFolders OPTIONS            MR warnings
-   MB locker                            MB writeable
+   MB addMessage  MESSAGE               MR log [LEVEL [,STRINGS]]
+   MB addMessages MESSAGE [, MESS...    MB message INDEX [,MESSAGE]
+   MB allMessageIds                     MB messageId MESSAGE-ID [,MESS...
+   MB close OPTIONS                     MB messages
+   MB create FOLDERNAME [, OPTIONS]     MB modified [BOOLEAN]
+   MB current [NUMBER|MESSAGE|MES...    MB name
+   MB delete                               new OPTIONS
+  MBD directory                         MB openSubFolder NAME [,OPTIONS]
+   MR errors                            MR report [LEVEL]
+   MB find MESSAGE-ID                   MR reportAll [LEVEL]
+   MB listSubFolders OPTIONS            MR trace [LEVEL]
+   MB locker                            MR warnings
 
 The extra methods for extension writers:
 
@@ -185,10 +184,11 @@ sub init($)
 
     $self->SUPER::init($args);
 
-    # About the index
-
-    my $directory            = $self->directory;
     my $folderdir            = $self->folderdir;
+    my $directory            = $self->directory;
+    return unless -d $directory;
+
+    # About the index
 
     $self->{MBM_keep_index}  = $args->{keep_index} || 0;
     $self->{MBM_index}       = $args->{index};
@@ -672,6 +672,8 @@ save your day.
 
 L<Mail::Box-Overview>
 
+For support and additional documentation, see http://perl.overmeer.net/mailbox/
+
 =head1 AUTHOR
 
 Mark Overmeer (F<mailbox@overmeer.net>).
@@ -680,9 +682,9 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.012.
+This code is beta, version 2.013.
 
-Copyright (c) 2001 Mark Overmeer. All rights reserved.
+Copyright (c) 2001-2002 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
