@@ -3,7 +3,7 @@ use strict;
 package Mail::Box::Mbox;
 use base 'Mail::Box';
 
-our $VERSION = 2.012;
+our $VERSION = 2.013;
 
 use Mail::Box::Mbox::Message;
 
@@ -52,19 +52,18 @@ L<Mail::Box> (MB), L<Mail::Reporter> (MR).
 
 The general methods for C<Mail::Box::Mbox> objects:
 
-   MB AUTOLOAD                          MR log [LEVEL [,STRINGS]]
-   MB addMessage  MESSAGE               MB message INDEX [,MESSAGE]
-   MB addMessages MESSAGE [, MESS...    MB messageId MESSAGE-ID [,MESS...
-   MB allMessageIds                     MB messages
-   MB close OPTIONS                     MB modified [BOOLEAN]
-      create FOLDERNAME, ARGS           MB name
-   MB current [NUMBER|MESSAGE|MES...       new OPTIONS
-   MB delete                            MB openSubFolder NAME [,OPTIONS]
-   MR errors                            MR report [LEVEL]
-      filename                          MR reportAll [LEVEL]
-   MB find MESSAGE-ID                   MR trace [LEVEL]
-      listSubFolders [OPTIONS]          MR warnings
-   MB locker                            MB writeable
+   MB addMessage  MESSAGE               MR log [LEVEL [,STRINGS]]
+   MB addMessages MESSAGE [, MESS...    MB message INDEX [,MESSAGE]
+   MB allMessageIds                     MB messageId MESSAGE-ID [,MESS...
+   MB close OPTIONS                     MB messages
+      create FOLDERNAME, ARGS           MB modified [BOOLEAN]
+   MB current [NUMBER|MESSAGE|MES...    MB name
+   MB delete                               new OPTIONS
+   MR errors                            MB openSubFolder NAME [,OPTIONS]
+      filename                          MR report [LEVEL]
+   MB find MESSAGE-ID                   MR reportAll [LEVEL]
+      listSubFolders [OPTIONS]          MR trace [LEVEL]
+   MB locker                            MR warnings
 
 The extra methods for extension writers:
 
@@ -910,6 +909,8 @@ distinguish between file- and directory-based folders in this respect.
 
 L<Mail::Box-Overview>
 
+For support and additional documentation, see http://perl.overmeer.net/mailbox/
+
 =head1 AUTHOR
 
 Mark Overmeer (F<mailbox@overmeer.net>).
@@ -918,9 +919,9 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.012.
+This code is beta, version 2.013.
 
-Copyright (c) 2001 Mark Overmeer. All rights reserved.
+Copyright (c) 2001-2002 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
